use std::{env, thread::sleep, time::Duration};

use cassandra_cpp::{stmt, Cluster, Session};

pub mod todo_repository;
pub mod user_repository;

static DEFAULT_KEYSPACE_NAME: &str = "rust_solidjs_cassandra";

pub fn init() -> Session {
    let keyspace_name = env::var("KEYSPACE_NAME").unwrap_or(DEFAULT_KEYSPACE_NAME.to_string());
    // Definitely set it so other modules can use it
    env::set_var("KEYSPACE_NAME", &keyspace_name);

    let mut cluster = Cluster::default();
    cluster.set_contact_points("127.0.0.1").unwrap(); // Panic if not successful
    let session = loop {
        match cluster.connect() {
            Ok(session) => break session,
            Err(_) => sleep(Duration::new(1, 0)),
        }
    };
    let query = stmt!(&format!(
        "CREATE KEYSPACE IF NOT EXISTS {keyspace_name}
             WITH replication = {{'class': 'SimpleStrategy', 'replication_factor': 1}};"
    ));

    session
        .execute(&query)
        .wait()
        .expect("Should create default keyspace if not exists");

    session
}
